# Copyright 1999-2017 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/net-ftp/atftp/atftp-0.7-r3.ebuild,v 1.6 2014/01/26 12:19:45 ago Exp $

EAPI=5
inherit eutils flag-o-matic systemd versionator rpm

MY_PV=$(replace_version_separator 2 '.dfsg-'  )
MY_PVV=$(replace_version_separator 3 'beta' $MY_PV )
MY_PVM=$(get_version_component_range 1-2 )
MY_PVR=$(get_version_component_range 1-3 )
OPSI="opsi40"
SUSE="openSUSE_13.2"
 
DESCRIPTION="Advanced TFTP implementation client/server"
HOMEPAGE="ftp://ftp.mamalinux.com/pub/atftp/"
SRC_URI="http://download.opensuse.org/repositories/home:/uibmz:/opsi:/${OPSI}/${SUSE}/src/opsi-atftp-${MY_PV}.src.rpm"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="amd64 arm ppc ppc64 ~s390 sparc x86"
IUSE="selinux tcpd readline pcre"

DEPEND="tcpd? ( sys-apps/tcp-wrappers )
	selinux? ( sec-policy/selinux-tftp )
	readline? ( sys-libs/readline )
	pcre? ( dev-libs/libpcre )"
RDEPEND="${DEPEND}
	!net-ftp/netkit-tftp
	!net-ftp/tftp-hpa
	!net-ftp/atftp"

S="${WORKDIR}"/opsi-atftp-${MY_PVM}.dfsg

src_prepare() {
	# epatch "${FILESDIR}"/atftp-${MY_PVM}-pcre.patch
	epatch "${FILESDIR}"/atftp-${MY_PVM}-password.patch
	epatch "${FILESDIR}"/atftp-${MY_PVM}-tests.patch
	# epatch "${FILESDIR}"/atftp-${MY_PVM}-glibc24.patch
	epatch "${FILESDIR}"/atftp-${MY_PVM}-blockno.patch
	epatch "${FILESDIR}"/atftp-${MY_PVM}-spaced_filename.patch
	epatch "${FILESDIR}"/atftp-${MY_PVM}-illreply.patch
	epatch "${FILESDIR}"/atftp-${MY_PVM}-filecase.patch
	# remove upstream's broken CFLAGS
	sed -i.orig -e \
	  '/^CFLAGS="-g -Wall -D_REENTRANT"/s,".*","",g' \
	  "${S}"/configure
}

src_configure() {
	append-flags -D_REENTRANT -DRATE_CONTROL
	econf \
		$(use_enable tcpd libwrap) \
		$(use_enable readline libreadline) \
		$(use_enable pcre libpcre) \
		--enable-mtftp
}

src_compile() {
	emake CFLAGS="${CFLAGS}"
}

src_install() {
	emake install DESTDIR="${D}"

	newinitd "${FILESDIR}"/atftp.init opsi-atftp
	newconfd "${FILESDIR}"/atftp.confd opsi-atftp

	systemd_dounit "${FILESDIR}"/atftp.service
	systemd_install_serviced "${FILESDIR}"/atftp.service.conf

	dodoc README* BUGS FAQ Changelog INSTALL TODO
	dodoc "${S}"/docs/*

	docinto test
	cd "${S}"/test
	dodoc load.sh mtftp.conf pcre_pattern.txt test.sh test_suite.txt
}
